'use client'
import { useState } from "react";
import FullCalendar from '@fullcalendar/react'
import dayGridPlugin from '@fullcalendar/daygrid'
import interactionPlugin, { Draggable } from "@fullcalendar/interaction";
import BootstrapTheme from "@fullcalendar/bootstrap";
import listPlugin from '@fullcalendar/list';
import useFollowUp from "@/feature/messenger/hooks/useFollowUp";
import { Calendar, X } from "react-feather";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import '@/feature/messenger/style/followup.css';
import { Button, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader, Select, SelectItem, Textarea } from "@nextui-org/react";
import '@/public/chat/assets/scss/vendors/_font-awesome.scss';
import { useTranslation } from "@/src/hooks/useTranslation";

type Calender = {
    events: Array<any>,
    categories: Array<any>,
    className: String,
    onGetEvents: Function,
    onAddNewEvent: Function,
    onUpdateEvent: Function,
    onDeleteEvent: Function,
    onGetCategories: Function,
}

const FollowUp = () => {

    const { trans } = useTranslation();
    const [selectedDay, setSelectedDay] = useState(0);
    const defaultListConversation = useConversationsStore(state => state.defaultListConversation);
    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const [selectedSession, setSelectedSession] = useState(0);
    const centered = true;
    const {
        openModalFollowUp,
        listFollowUpEvents,
        openFollowUpOptions,
        openFollowUpNewEvent,
        closeFollowUpNewEvent,
        onDropFollowUp,
        dateSelected,
        typeOption,
        handleCreateEvent,
        handleFormChange,
        loading,
        formData,
        openFollowUpEditEvent,
        openFollowUpDeleteEvent,
        handleDeleteEvent,
        handleOpenModalFollowUp
    } = useFollowUp();

    const toggleFollowUp = () => {
        handleOpenModalFollowUp()
    }

    const toggle = () => {
        handleOpenModalFollowUp()
    }

    const handleDateClick = (arg: any) => {
        setSelectedDay(arg);
    }

    const handleSelectSesion = () => {
        let selectedValue = '';
        if (typeOption == 'edit' && formData.sesions != undefined) selectedValue = formData.sesions;
        else if (typeOption == 'add') selectedValue = selectedConversation.sesion;
        return new Set([selectedValue]);
    }

    const componentSelectItems = () => {
        let component = [];
        {
            typeOption == 'add' && defaultListConversation.map((item: any) => (
                component.push(
                    <SelectItem value={item.sesion} key={item.sesion} textValue={item.sesion}>
                        {item.nombre != "" ? item.nombre + " - " + item.sesion : item.sesion}
                    </SelectItem>
                )
            ))
        }
        {
            typeOption == 'edit' &&
                component.push(
                    <SelectItem value={formData.sesions} textValue={formData.sesions} key={formData.sesions}>
                        {formData.sesions}
                    </SelectItem>
                )
        }

        return component;
    }
    return (
        <>
            <Modal
                isOpen={openModalFollowUp}
                onOpenChange={() => toggleFollowUp()}
                size="5xl"
                scrollBehavior="inside"
            >
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader className="flex justify-start items-center gap-2">
                                <Calendar size={20} /> {trans('modal_conversations_follow_up_title')}
                            </ModalHeader>
                            <ModalBody>
                                <div className="w-full">
                                    <div>
                                        <div className="mx-auto p-4">
                                            <FullCalendar
                                                plugins={[
                                                    BootstrapTheme,
                                                    dayGridPlugin,
                                                    interactionPlugin,
                                                    listPlugin
                                                ]}
                                                initialView="dayGridMonth"
                                                slotDuration={"00:15:00"}
                                                handleWindowResize={true}
                                                themeSystem="bootstrap"
                                                headerToolbar={{
                                                    left: "prev,next today",
                                                    center: "title",
                                                    right: "dayGridMonth,dayGridWeek,dayGridDay,listWeek",
                                                }}
                                                editable={true}
                                                droppable={true}
                                                selectable={true}
                                                events={listFollowUpEvents}
                                                dateClick={openFollowUpNewEvent}
                                                eventClick={openFollowUpNewEvent}
                                                eventDrop={onDropFollowUp}
                                                validRange={{ start: new Date() }}
                                            />
                                        </div>
                                    </div>
                                </div>
                            </ModalBody>
                        </>
                    )}
                </ModalContent>
            </Modal >
            <Modal isOpen={openFollowUpOptions} onOpenChange={() => closeFollowUpNewEvent()}>
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>
                                {typeOption == 'add' && <div>{trans('modal_conversations_follow_up_create_title')} {dateSelected}</div>}
                                {typeOption == 'edit' && <div>{trans('modal_conversations_follow_up_edit_title')} {dateSelected}</div>}
                                {typeOption == 'delete' && <div>{trans('modal_conversations_follow_up_delete_title')} {dateSelected}</div>}
                                {typeOption == 'options' && <div>{trans('modal_conversations_follow_up_options_title')} {dateSelected}</div>}
                            </ModalHeader>
                            <ModalBody>
                                <div className="w-full">
                                    <div className="w-full gap-2">
                                        <div className="w-full">
                                            {(typeOption == 'add' || typeOption == 'edit') &&
                                                <form onSubmit={handleCreateEvent}>
                                                    <div>
                                                        <div>
                                                            <Textarea
                                                                label={trans('modal_conversations_follow_up_textarea_description_title')}
                                                                placeholder={trans('modal_conversations_follow_up_textarea_description_placeholder_title')}
                                                                name="commentary"
                                                                onChange={handleFormChange}
                                                                value={formData.commentary}
                                                                className="w-full"
                                                            />
                                                        </div>
                                                        <div className="mt-3">
                                                            <Select name="sesions" onChange={handleFormChange} disabled={typeOption == 'edit'}
                                                                label={trans('modal_conversations_follow_up_select_session_title')}
                                                                placeholder={trans('modal_conversations_follow_up_select_session_placeholder_title')}
                                                                defaultSelectedKeys={handleSelectSesion()}
                                                                selectedKeys={handleSelectSesion()}
                                                            >
                                                                {componentSelectItems()}
                                                            </Select>
                                                        </div>
                                                    </div>
                                                    <ModalFooter>
                                                        <Button color="danger" onClick={() => closeFollowUpNewEvent()} isDisabled={loading}>
                                                            {trans('modal_conversations_follow_up_button_cancel_title')}
                                                        </Button>
                                                        <Button color="primary" className="flex justify-center items-center" type="submit" isLoading={loading} style={{ display: typeOption == 'add' ? 'block' : 'none' }}>
                                                            {(loading && typeOption == 'add') ? trans('modal_conversations_follow_up_button_create_loading_title') : trans('modal_conversations_follow_up_button_create_title')}
                                                        </Button>
                                                        <Button color="primary" className="flex justify-center items-center" type="submit" isLoading={loading} style={{ display: typeOption == 'edit' ? 'block' : 'none' }}>
                                                            {(loading && typeOption == 'edit') ? trans('modal_conversations_follow_up_button_edit_loading_title') : trans('modal_conversations_follow_up_button_edit_title')}
                                                        </Button>
                                                    </ModalFooter>
                                                </form>
                                            }
                                            {typeOption == 'options' &&
                                                <div>
                                                    <div className="text-center text-lg p-2">
                                                        <h3 className="text-center font-semibold">{trans('modal_conversations_follow_up_confim_options_title')}</h3>
                                                    </div>
                                                    <div className="text-center p-2">
                                                        <strong>
                                                            {formData.commentary}
                                                        </strong>
                                                    </div>
                                                    <ModalFooter>
                                                        <Button color="danger" onClick={() => openFollowUpDeleteEvent()} disabled={loading}>
                                                            {trans('modal_conversations_follow_up_button_delete_title')}
                                                        </Button>
                                                        <Button color="primary" onClick={() => openFollowUpEditEvent()} disabled={loading}>
                                                            {trans('modal_conversations_follow_up_button_edit_title')}
                                                        </Button>
                                                    </ModalFooter>
                                                </div>
                                            }
                                            {typeOption == 'delete' &&
                                                <div>
                                                    <div className="text-center text-lg p-2">
                                                        <h3>{trans('modal_conversations_follow_up_confim_delete_title')}</h3>
                                                        <p>{trans('modal_conversations_follow_up_confim_sub_title')}: {formData.commentary}</p>
                                                    </div>
                                                    <form onSubmit={handleDeleteEvent}>
                                                        <ModalFooter>
                                                            <Button color="danger" onClick={() => closeFollowUpNewEvent()} disabled={loading}>
                                                                {trans('modal_conversations_follow_up_button_cancel_title')}
                                                            </Button>
                                                            <Button color="primary" type="submit" disabled={loading}>
                                                                {loading ? trans('modal_conversations_follow_up_button_delete_loading_title') : trans('modal_conversations_follow_up_button_delete_title')}
                                                            </Button>
                                                        </ModalFooter>
                                                    </form>
                                                </div>
                                            }
                                        </div>
                                    </div>
                                </div>
                            </ModalBody>
                        </>
                    )}
                </ModalContent>
            </Modal>
        </>
    )
}

export default FollowUp